package com.gihon.common.http;

import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.springframework.http.HttpStatus;

/**
 * Http 请求结果封装
 *
 * @author Mr.Xi
 * @date 2020/01/13
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class HttpResult<T> {

    /**
     * 返回结果代码
     */
    private int code = 200;

    /**
     * 具体的错误信息
     */
    private String msg = "ok";

    /**
     * 返回结果数据
     */
    private T data;

    public static HttpResult error() {
        return error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"服务器异常，请联系管理员");
    }

    public static HttpResult error(String msg) {
        return error(HttpStatus.INTERNAL_SERVER_ERROR.value(),msg);
    }

    public static HttpResult error(String msg,Object data) {
        return error(HttpStatus.INTERNAL_SERVER_ERROR.value(),msg).setData(data);
    }


    public static HttpResult error(int code, String msg) {
        HttpResult result = new HttpResult();
        result.setCode(code);
        result.setMsg(msg);
        return result;
    }

    public static HttpResult error(int code, String msg,Object data) {
        HttpResult result = new HttpResult();
        result.setCode(code);
        result.setMsg(msg);
        result.setData(data);
        return result;
    }
    public static HttpResult ok(String msg,Object data) {
        HttpResult result = new HttpResult();
        result.setMsg(msg);
        result.setData(data);
        return result;
    }

    public static HttpResult ok(Object data) {
        HttpResult result = new HttpResult();
        result.setData(data);
        return result;
    }

    public static HttpResult ok() {
        return new HttpResult();
    }
}
